import { InfluxDB } from '@influxdata/influxdb-client';
import { RequestOptions } from '../APIBase';
import { PasswordResetBody, UserResponse } from './types';
export interface GetMeRequest {
}
export interface PutMePasswordRequest {
    auth?: {
        user: string;
        password: string;
    };
    /** New password */
    body: PasswordResetBody;
}
/**
 * Me API
 */
export declare class MeAPI {
    private base;
    /**
     * Creates MeAPI
     * @param influxDB - an instance that knows how to communicate with InfluxDB server
     */
    constructor(influxDB: InfluxDB);
    /**
     * Retrieve the currently authenticated user.
     * See {@link https://docs.influxdata.com/influxdb/v2.1/api/#operation/GetMe }
     * @param request - request parameters and body (if supported)
     * @param requestOptions - optional transport options
     * @returns promise of response
     */
    getMe(request?: GetMeRequest, requestOptions?: RequestOptions): Promise<UserResponse>;
    /**
     * Update a password.
     * See {@link https://docs.influxdata.com/influxdb/v2.1/api/#operation/PutMePassword }
     * @param request - request parameters and body (if supported)
     * @param requestOptions - optional transport options
     * @returns promise of response
     */
    putMePassword(request: PutMePasswordRequest, requestOptions?: RequestOptions): Promise<void>;
}
//# sourceMappingURL=MeAPI.d.ts.map