import { InfluxDB } from '@influxdata/influxdb-client';
import { RequestOptions } from '../APIBase';
export interface PostWriteRequest {
    /** Data in line protocol format.
  
  To send compressed data, do the following:
  
    1. Use [GZIP](https://www.gzip.org/) to compress the line protocol data.
    2. In your request, send the compressed data and the
       `Content-Encoding: gzip` header.
  
  #### Related guides
  
  - [Best practices for optimizing writes](https://docs.influxdata.com/influxdb/v2.2/write-data/best-practices/optimize-writes/).
   */
    body: string;
    /** The destination organization for writes.
  The database writes all points in the batch to this organization.
  If you provide both `orgID` and `org` parameters, `org` takes precedence.
   */
    org: string;
    /** The ID of the destination organization for writes.
  If both `orgID` and `org` are specified, `org` takes precedence.
   */
    orgID?: string;
    /** The destination bucket for writes. */
    bucket: string;
    /** The precision for unix timestamps in the line protocol batch. */
    precision?: any;
}
/**
 * Write API
 */
export declare class WriteAPI {
    private base;
    /**
     * Creates WriteAPI
     * @param influxDB - an instance that knows how to communicate with InfluxDB server
     */
    constructor(influxDB: InfluxDB);
    /**
     * Write data.
     * See {@link https://docs.influxdata.com/influxdb/v2.1/api/#operation/PostWrite }
     * @param request - request parameters and body (if supported)
     * @param requestOptions - optional transport options
     * @returns promise of response
     */
    postWrite(request: PostWriteRequest, requestOptions?: RequestOptions): Promise<void>;
}
//# sourceMappingURL=WriteAPI.d.ts.map